/*
 * Copyright (c) 2013, Patrick Moawad
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.google.code.validationframework.swing.dataprovider;

import com.google.code.validationframework.api.dataprovider.DataProvider;

import javax.swing.JList;
import java.util.ArrayList;
import java.util.Collection;

/**
 * Data provider retrieving the selected indices of a list.
 *
 * @see DataProvider
 * @see JList
 * @see JList#getSelectedIndices()
 * @see JListSelectedIndexProvider
 * @see JListSelectedValueProvider
 * @see JListSelectedValuesProvider
 */
public class JListSelectedIndicesProvider implements DataProvider<Collection<Integer>> {

    /**
     * List to get the selected indices from.
     */
    private final JList list;

    /**
     * Constructor specifying the list to get the selected indices from.
     *
     * @param list List to get the selected index from.
     */
    public JListSelectedIndicesProvider(final JList list) {
        this.list = list;
    }

    /**
     * Gets the component providing the data to be validated.
     *
     * @return Component providing the data to be validated.
     */
    public JList getComponent() {
        return list;
    }

    /**
     * @see DataProvider#getData()
     */
    @Override
    public Collection<Integer> getData() {
        final Collection<Integer> indices = new ArrayList<Integer>();
        for (final int index : list.getSelectedIndices()) {
            indices.add(index);
        }
        return indices;
    }
}
